@@ -28,7 +28,11 @@ import tempfile
 import time
 import multiprocessing
 
+from paunch import runner as containers_runner
+
 logger = None
+RUNNER = containers_runner.DockerRunner(
+        'docker-puppet')
 
 
 def get_logger():
@@ -225,6 +229,7 @@ with open(sh_script, 'w') as script_file:
     set +e
     # $::deployment_type in puppet-tripleo
     export FACTER_deployment_type=containers
+    export FACTER_uuid=$(cat /sys/class/dmi/id/product_uuid | tr '[:upper:]' '[:lower:]')
     FACTER_hostname=$HOSTNAME /usr/bin/puppet apply --summarize \
     --detailed-exitcodes --color=false --logdest syslog --logdest console --modulepath=/etc/puppet/modules:/usr/share/openstack-puppet/modules $TAGS /etc/config.pp
     rc=$?
@@ -285,12 +290,14 @@ def mp_puppet_config((config_volume, puppet_tags, manifest, config_image, volume
             man_file.write('include ::tripleo::packages\n')
             man_file.write(manifest)
 
-        rm_container('docker-puppet-%s' % config_volume)
+        uname = RUNNER.unique_container_name('docker-puppet-%s' %
+                                             config_volume)
+        rm_container(uname)
         pull_image(config_image)
 
         dcmd = ['/usr/bin/docker', 'run',
                 '--user', 'root',
-                '--name', 'docker-puppet-%s' % config_volume,
+                '--name', uname,
                 '--env', 'PUPPET_TAGS=%s' % puppet_tags,
                 '--env', 'NAME=%s' % config_volume,
                 '--env', 'HOSTNAME=%s' % short_hostname(),
@@ -299,7 +306,7 @@ def mp_puppet_config((config_volume, puppet_tags, manifest, config_image, volume
                 '--volume', '/etc/localtime:/etc/localtime:ro',
                 '--volume', '%s:/etc/config.pp:ro,z' % tmp_man.name,
                 '--volume', '/etc/puppet/:/tmp/puppet-etc/:ro,z',
-                '--volume', '/usr/share/openstack-puppet/modules/:/usr/share/openstack-puppet/modules/:ro,z',
+                '--volume', '/usr/share/openstack-puppet/modules/:/usr/share/openstack-puppet/modules/:ro',
                 '--volume', '%s:/var/lib/config-data/:z' % os.environ.get('CONFIG_VOLUME_PREFIX', '/var/lib/config-data'),
                 '--volume', 'tripleo_logs:/var/log/tripleo/',
                 # Syslog socket for puppet logs
@@ -348,7 +355,7 @@ def mp_puppet_config((config_volume, puppet_tags, manifest, config_image, volume
             if cmd_stderr:
                 log.debug(cmd_stderr)
             # only delete successful runs, for debugging
-            rm_container('docker-puppet-%s' % config_volume)
+            rm_container(uname)
 
         log.info('Finished processing puppet configs for %s' % (config_volume))
         return subproc.returncode
