@@ -22,6 +22,22 @@ import yaml
 __tht_root_dir = os.path.dirname(os.path.dirname(__file__))
 
 
+def _shutil_copy_if_not_same(src, dst):
+    """Copy with shutil ignoring the same file errors."""
+    if hasattr(shutil, 'SameFileError'):
+        try:
+            shutil.copy(src, dst)
+        except shutil.SameFileError:
+            pass
+    else:
+        try:
+            shutil.copy(src, dst)
+        except Exception as ex:
+            if 'are the same file' in six.text_type(ex):
+                pass
+            else:
+                raise
+
 def parse_opts(argv):
     parser = argparse.ArgumentParser(
         description='Configure host network interfaces using a JSON'
@@ -42,6 +58,10 @@ def parse_opts(argv):
     parser.add_argument('-o', '--output-dir', metavar='OUTPUT_DIR',
                         help="""Output dir for all the templates""",
                         default='')
+    parser.add_argument('-c', '--clean',
+                        action='store_true',
+                        help=("""clean the templates dir by deleting """
+                              """generated templates"""))
     opts = parser.parse_args(argv[1:])
 
     return opts
@@ -130,10 +150,20 @@ def process_templates(template_path, role_data_path, output_dir,
             # the command multiple times with the same output_dir.
             out_dir = subdir
             if output_dir:
-                out_dir = os.path.join(output_dir, subdir)
+                if template_path != '.':
+                   # strip out base path if not default
+                   temp = out_dir.split(template_path)[1]
+                   out_dir = temp[1:] if temp.startswith('/') else temp
+                out_dir = os.path.join(output_dir, out_dir)
                 if not os.path.exists(out_dir):
                     os.mkdir(out_dir)
 
+            # Ensure template is on its expected search path
+            # for upcoming parsing and rendering
+            for f in files:
+                if f.endswith('.j2') and output_dir:
+                    _shutil_copy_if_not_same(os.path.join(subdir, f), out_dir)
+
             for f in files:
                 file_path = os.path.join(subdir, f)
                 # We do three templating passes here:
@@ -157,6 +187,14 @@ def process_templates(template_path, role_data_path, output_dir,
                                  os.path.basename(f).replace('.role.j2.yaml',
                                                              '.yaml')])
                             out_f_path = os.path.join(out_dir, out_f)
+                            if ('network/config' in file_path and
+                                r_map[role].get('deprecated_nic_config_name')):
+                                d_name = r_map[role].get(
+                                    'deprecated_nic_config_name')
+                                out_f_path = os.path.join(out_dir, d_name)
+                            elif ('network/config' in file_path):
+                                d_name = "%s.yaml" % role.lower()
+                                out_f_path = os.path.join(out_dir, d_name)
                             if not (out_f_path in excl_templates):
                                 if '{{role.name}}' in template_data:
                                     j2_data = {'role': r_map[role],
@@ -175,7 +213,7 @@ def process_templates(template_path, role_data_path, output_dir,
                                                        False):
                                         j2_data['disable_constraints'] = True
                                     _j2_render_to_file(
-                                        template_data,j2_data,
+                                        template_data, j2_data,
                                         out_f_path, overwrite)
 
                             else:
@@ -215,15 +253,75 @@ def process_templates(template_path, role_data_path, output_dir,
                         _j2_render_to_file(template_data, j2_data, out_f_path,
                                            overwrite)
                 elif output_dir:
-                    shutil.copy(os.path.join(subdir, f), out_dir)
+                    _shutil_copy_if_not_same(os.path.join(subdir, f), out_dir)
 
     else:
         print('Unexpected argument %s' % template_path)
 
+def clean_templates(base_path, role_data_path, network_data_path):
+
+    def delete(f):
+        if os.path.exists(f):
+            print("Deleting %s" % f)
+            os.unlink(f)
+
+    for root, dirs, files in os.walk(base_path):
+        for f in files:
+            if f.endswith('.j2.yaml'):
+                rendered_path = os.path.join(
+                    root, '%s.yaml' % f.split('.j2.yaml')[0])
+                delete(rendered_path)
+
+    with open(network_data_path) as network_data_file:
+        network_data = yaml.safe_load(network_data_file)
+
+    for network in network_data:
+        network_path = os.path.join(
+            'network', '%s.yaml' % network['name_lower'])
+        network_from_pool_path = os.path.join(
+            'network', '%s_from_pool.yaml' % network['name_lower'])
+        network_v6_path = os.path.join(
+            'network', '%s_v6.yaml' % network['name_lower'])
+        network_from_pool_v6_path = os.path.join(
+            'network', '%s_from_pool_v6.yaml' % network['name_lower'])
+        ports_path = os.path.join(
+            'network', 'ports', '%s.yaml' % network['name_lower'])
+        ports_from_pool_path = os.path.join(
+            'network', 'ports', '%s_from_pool.yaml' % network['name_lower'])
+        ports_v6_path = os.path.join(
+            'network', 'ports', '%s_v6.yaml' % network['name_lower'])
+        ports_from_pool_v6_path = os.path.join(
+            'network', 'ports', '%s_from_pool_v6.yaml' % network['name_lower'])
+
+        delete(network_path)
+        delete(network_from_pool_path)
+        delete(network_v6_path)
+        delete(network_from_pool_v6_path)
+        delete(ports_path)
+        delete(ports_from_pool_path)
+        delete(ports_v6_path)
+        delete(ports_from_pool_v6_path)
+
+    with open(role_data_path) as role_data_file:
+        role_data = yaml.safe_load(role_data_file)
+
+    for role in role_data:
+        role_path = os.path.join(
+            'puppet', '%s-role.yaml' % role['name'].lower())
+        host_config_and_reboot_path = os.path.join(
+            'extraconfig', 'pre_network',
+            '%s-host_config_and_reboot.yaml' % role['name'].lower())
+
+        delete(role_path)
+        delete(host_config_and_reboot_path)
+
 opts = parse_opts(sys.argv)
 
 role_data_path = os.path.join(opts.base_path, opts.roles_data)
 network_data_path = os.path.join(opts.base_path, opts.network_data)
 
-process_templates(opts.base_path, role_data_path, opts.output_dir,
-                  network_data_path, (not opts.safe))
+if opts.clean:
+    clean_templates(opts.base_path, role_data_path, network_data_path)
+else:
+    process_templates(opts.base_path, role_data_path, opts.output_dir,
+                      network_data_path, (not opts.safe))
